---
title: Homepage
layout: default
---

# Intercultural Dialogue and Multilingualism in Post-Conquest England: A Database of French Literary Manuscripts Produced Between 1100-1550

The Norman Conquest of 1066 is often understood as a major turning point in the linguistic history of England, since it placed French-speaking Normans in the high ranks of both secular and religious administration. The Conquest has become so important for the history of the English language that ir is often treated as the end of the Old English period and the start of the Middle English period.  Yet scholars have become increasingly interested in evaluating the significance of the Conquest for England’s linguistic history.  As Douglas Kibbee (1991) and others have pointed out, the Normans had, long before the Conquest, established powerful ties to England, including, perhaps most famously, the 1002 marriage between the Anglo-Saxon king Æthelred the Unready and Emma of Normandy.  And whether the Conquest itself led to significant linguistic upheaval has been subject to much debate, with scholars questioning how far, and in which contexts, French permeated medieval society.

This database aims to shed light on the status of French following the Norman Conquest, including who read it, when, and in which contexts. The project approaches these questions through an exploration of all manuscripts produced between 1100 and 1550 that contain French literature. Manuscripts have been chosen as a focal point because, as unique written witnesses to language use, they provide unmatched large-scale data about England’s linguistic situation.

## Credits

This catalogue was produced thanks to a research grant from the Europeana Foundation.  I collected the contents of the catalogue from existing catalogue records and primary research over the course of four months, and the website and programming for the data analysis component of the project was created by Ben Companjen at Leiden University’s Centre for Digital Scholarship. 

I would like to express my sincere thanks to the Europeana Foundation for the financial support that enabled this project, to the Leiden University Centre for the Arts in Society (LUCAS) for research travel support, and to Ben Companjen for his technical expertise and support.  I am also grateful to the staff and librarians of Cambridge University Library for letting me use their collections, and to the various libraries and archives that have made their collections available to researchers through digitization, without which this project would not have been possible.

## Contents of this Catalogue

The database is aimed at describing all manuscripts copied in England between 1100 and 1550 that contain French literature. The list of manuscripts was compiled from the “Index of MSS” given in Ruth Dean and Maureen Boulton’s *Anglo-Norman Literature: A Guide to Texts and Manuscripts* (1999). To date, all manuscripts from Dean and Boulton’s list are included in the catalogye except for those housed in Oxford. The list does not include manuscripts copied on the continent (those marked with an asterisk on Dean and Boulton’s list).

## Methodology

Manuscripts that once circulated as separate, holistic objects were in many cases been bound with other manuscripts or with other material, either before or after the end point of this investigation in 1550. My aim has been to describe these manuscripts in their original forms, since the goals of this database include developing a better understanding of how French texts circulated in medieval England and in which contexts they circulated. This means that manuscripts that clearly circulated separately in the medieval period have been treated as separate objects in the database, and the foliation and dates given in the database for these manuscripts refer, as much as possible, to the original form of each manuscript. The database also includes manuscripts that have been lost or destroyed, but that survived long enough to have been described in modern catalogues. Since the database describes manuscripts in their medieval forms, it should be used critically by those interested in the modern shape and contexts of the manuscripts described, and links to original catalogue records (with descriptions of the manuscripts in their modern forms) have been provided wherever possible.

For each manuscript I have recorded the number of folia sides that contain the languages under exploration: French, Latin and English. I have also included any other languages found, which includes Hebrew and Greek. In the interest of consistency, I have aimed to record, under a manuscript’s contents, any writing containing four or more lines of text; some interesting or note-worthy writing under four lines has also been recorded, but this has been placed in the “Notes” category. An exception to this rule has been made for glosses; although these often consist of fewer than four “lines of text” they operate as part of a larger textual framework and therefore represent valuable linguistic data.

I have aimed, wherever possible, to draw on open access data, or data that has entered the public domain. This has, in some cases, meant a reliance on late nineteenth and early twentieth-century manuscript catalogues, and this catalogue may not, therefore, always reflect the most up-to-date description information. 
Since my interest is in the medieval contexts and owners of these manuscripts, the list of owners for each manuscript is limited to those who owned the manuscript before 1550.  Owner information is based on catalogue data and on Neil Ker and Andrew Watson’s *Medieval Libraries of Great Britain*.  In a few cases, all noted, I have supplied additional information about owners based on my own research.  The goal of tracking large-scale ownership patterns has necessitated the rather blunt classification of owners as either “clerical” or “lay” based on their position at the time of manuscript ownership; as such, I use “clerical” not in the sense of “one who is ordained” but in the broader, popular sense of the term, as a way of describing one whose primary social function is religious. This means that individuals such as nuns and rectors have been classified as “clerical.”
Where necessary and possible, I have verified the languages in manuscripts in person; I have indicated in the “Notes” column which manuscripts have been verified. 

Krista A. Murchison  
Lecturer of Medieval English and Medieval French Literature  
Leiden University


See the [manuscripts]({{ site.baseurl }}{% link manuscripts.html %}) !

See the [language use]({{ site.baseurl }}{% link manuscripts-stats.html %}) !